@@ -1,13 +1,15 @@
 import factory
 
 from django.contrib.auth import get_user_model
-from rest_framework.authtoken.models import Token
+
+from user_management.api.models import AuthToken
 
 
 class UserFactory(factory.DjangoModelFactory):
     FACTORY_FOR = get_user_model()
-    name = factory.Sequence(lambda i: 'Test User {}'.format(i))
-    email = factory.Sequence(lambda i: 'email{}@example.com'.format(i))
+
+    name = factory.Sequence('Test User {}'.format)
+    email = factory.Sequence('email{}@example.com'.format)
     is_active = True
 
     @factory.post_generation
@@ -18,8 +20,8 @@ class UserFactory(factory.DjangoModelFactory):
             self.save()
 
 
-class TokenFactory(factory.DjangoModelFactory):
-    FACTORY_FOR = Token
+class AuthTokenFactory(factory.DjangoModelFactory):
+    FACTORY_FOR = AuthToken
 
     key = factory.Sequence('key{}'.format)
     user = factory.SubFactory(UserFactory)
